@@ -31,7 +31,8 @@ from .util import (
     _check_leverage,
     _check_slippage,
     _check_collateral,
-    _normalize
+    _normalize,
+    _estimate_gas_fee
 )
 
 from .constants import (
@@ -143,6 +144,7 @@ class Polysynth:
 
         except PolysynthException as pe:
             print(pe)
+            sys.exit()
 
     def input_price(
         self,
@@ -163,7 +165,7 @@ class Polysynth:
         '''
         try:
             price = _normalize(self._input_price(amm, side, quoteAssetAmount)[0])
-            return Response(StatusCode.OK.value, None, None, data= {"amount": price })
+            return Response(StatusCode.OK.value, None, None, data= {"amount": abs(price) })
         except PolysynthException as e:
             return e
     
@@ -196,7 +198,7 @@ class Polysynth:
                 _side_str_to_int(side),
                 _int_to_bignum(baseAssetAmount)
             ).call()
-            return Response(StatusCode.OK.value, None, None, data= { "amount": _normalize(price[0]) })
+            return Response(StatusCode.OK.value, None, None, data= { "amount": abs(_normalize(price[0])) })
         except PolysynthException as e:
             return e
 
@@ -247,6 +249,8 @@ class Polysynth:
             receipt = self._build_and_send_tx(func, tx_params)
             tx = self.w3.eth.wait_for_transaction_receipt(receipt, timeout=1000)
 
+            time.sleep(2)
+
             position = self._trader_position(amm)
             _price = round(position[2]/position[0], 4)
             _size = _normalize(position[0])
@@ -882,7 +886,7 @@ class Polysynth:
 
         _side = 0 if _size > 0 else 1
 
-        _sold_token = amm_reader.getStableTokenAmount(amm_contract_addr, _side, _size).call()[0]
+        _sold_token = amm_reader.getStableTokenAmount(amm_contract_addr, _side, abs(_size)).call()[0]
 
         _stable_token_limit = _sold_token*(1 - slippage) if _size > 0 else _sold_token*(1 + slippage)
 
@@ -1129,13 +1133,12 @@ class Polysynth:
 
     def _get_tx_params(self, value: Wei = Wei(0), gas: Wei = Wei(5000000)) -> TxParams:
         """Get generic transaction parameters."""
+        gasFee = _estimate_gas_fee("standard", self.network)
         return {
             "from": _addr_to_str(self.address),
             "value": value,
-            "gas": gas,
-            # "gasPrice": Web3.toWei(80, 'gwei'),
-            # "maxFeePerGas": 2000000000,
-            # 'maxPriorityFeePerGas': 1000000000,
+            "maxFeePerGas": Web3.toWei(gasFee['maxFee'], 'gwei'),
+            'maxPriorityFeePerGas': Web3.toWei(gasFee['maxPriorityFee'], 'gwei'),
             "nonce": max(
                 self.last_nonce, self.w3.eth.get_transaction_count(self.address)
             ),
